The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Package {BUSfinancial}


Type: Package
Title: Economic Analysis of Islamic Commercial Bank Financial Time Series in Indonesia
Version: 0.1.0
Description: Provides simple economic indicators for analyzing financial position time series of Islamic Commercial Banks in Indonesia.
License: GPL-3
Encoding: UTF-8
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-24 00:43:03 UTC; HP
Author: Fadhlul Mubarak ORCID iD [aut, cre], Vinny Yuliani Sundara ORCID iD [aut]
Maintainer: Fadhlul Mubarak <mubarakfadhlul@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-03 13:20:02 UTC

BUS Financial Signal

Description

Classifies the monthly financial dynamics of an Islamic Commercial Bank based on financing growth and third-party funds (DPK) growth.

Usage

bus_financial_signal(financing, dpk)

Arguments

financing

Total financing.

dpk

Third-party funds.

Value

A data frame containing financing growth, DPK growth, and financial signal.

Examples

bus_financial_signal(
  financing = c(100, 105, 110, 108),
  dpk = c(120, 125, 123, 130)
)


Financing Structure

Description

Calculates the percentage composition of Islamic financing by contract type.

Usage

financing_structure(
  mudharabah,
  musyarakah,
  murabahah,
  qardh,
  istishna,
  ijarah_nonbank,
  ijarah_bank
)

Arguments

mudharabah

Mudharabah financing.

musyarakah

Musyarakah financing.

murabahah

Murabahah receivables.

qardh

Qardh receivables.

istishna

Istishna receivables.

ijarah_nonbank

Ijarah financing to non-bank parties.

ijarah_bank

Ijarah financing to other banks.

Value

A data frame containing financing composition in percentage.

Examples

financing_structure(
  mudharabah = c(10, 12),
  musyarakah = c(30, 35),
  murabahah = c(50, 55),
  qardh = c(5, 6),
  istishna = c(3, 4),
  ijarah_nonbank = c(2, 3),
  ijarah_bank = c(1, 1)
)


Financing to DPK Ratio

Description

Calculates the ratio of total financing to third-party funds (DPK).

Usage

financing_to_dpk(profit_sharing, receivables, ijarah, salam, istishna, dpk)

Arguments

profit_sharing

Profit-sharing financing.

receivables

Receivables.

ijarah

Ijarah financing including lease receivables.

salam

Salam financing.

istishna

Istishna assets under construction.

dpk

Third-party funds.

Value

A numeric vector containing the Financing to DPK ratio.

Examples

financing_to_dpk(
  profit_sharing = c(100, 110, 120),
  receivables = c(200, 210, 220),
  ijarah = c(50, 55, 60),
  salam = c(10, 10, 12),
  istishna = c(5, 6, 7),
  dpk = c(500, 520, 550)
)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.